@@ -29,24 +29,44 @@
 G_BEGIN_DECLS
 
 GList		*gs_plugin_loader_get_installed		(GsPluginLoader	*plugin_loader,
-							 GsPluginLoaderFlags flags,
+							 GsPluginRefineFlags flags,
+							 GCancellable	*cancellable,
+							 GError		**error);
+GList		*gs_plugin_loader_search		(GsPluginLoader	*plugin_loader,
+							 const gchar	*value,
+							 GsPluginRefineFlags flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GList		*gs_plugin_loader_get_updates		(GsPluginLoader	*plugin_loader,
-							 GsPluginLoaderFlags flags,
+							 GsPluginRefineFlags flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GList		*gs_plugin_loader_get_popular		(GsPluginLoader	*plugin_loader,
-							 GsPluginLoaderFlags flags,
+							 GsPluginRefineFlags flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GList		*gs_plugin_loader_get_categories	(GsPluginLoader	*plugin_loader,
-							 GsPluginLoaderFlags flags,
+							 GsPluginRefineFlags flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GList		*gs_plugin_loader_get_category_apps	(GsPluginLoader	*plugin_loader,
 							 GsCategory	*category,
-							 GsPluginLoaderFlags flags,
+							 GsPluginRefineFlags flags,
+							 GCancellable	*cancellable,
+							 GError		**error);
+gboolean	 gs_plugin_loader_app_refine		(GsPluginLoader	*plugin_loader,
+							 GsApp		*app,
+							 GsPluginRefineFlags flags,
+							 GCancellable	*cancellable,
+							 GError		**error);
+gboolean	 gs_plugin_loader_app_action		(GsPluginLoader	*plugin_loader,
+							 GsApp		*app,
+							 GsPluginLoaderAction action,
+							 GCancellable	*cancellable,
+							 GError		**error);
+GsApp		*gs_plugin_loader_get_app_by_id		(GsPluginLoader	*plugin_loader,
+							 const gchar	*id,
+							 GsPluginRefineFlags flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
