@@ -44,6 +44,8 @@ struct GsPluginLoaderPrivate
 	GMutex			 app_cache_mutex;
 	GHashTable		*app_cache;
 	GHashTable		*icon_cache;
+	GSettings		*settings;
+
 	gchar			**compatible_projects;
 
 	GList			*queued_installs;
@@ -55,6 +57,7 @@ G_DEFINE_TYPE (GsPluginLoader, gs_plugin_loader, G_TYPE_OBJECT)
 enum {
 	SIGNAL_STATUS_CHANGED,
 	SIGNAL_PENDING_APPS_CHANGED,
+	SIGNAL_UPDATES_CHANGED,
 	SIGNAL_LAST
 };
 
@@ -119,39 +122,8 @@ gs_plugin_loader_dedupe (GsPluginLoader *plugin_loader, GsApp *app)
 		goto out;
 	}
 
-	/* wait for all the properties to be set */
-	g_object_freeze_notify (G_OBJECT (new_app));
-
-	/* an [updatable] installable package is more information than
-	 * just the fact that something is installed */
-	if (gs_app_get_state (app) == GS_APP_STATE_UPDATABLE &&
-	    gs_app_get_state (new_app) == GS_APP_STATE_INSTALLED) {
-		/* we have to do the little dance to appease the
-		 * angry gnome controlling the state-machine */
-		gs_app_set_state (new_app, GS_APP_STATE_UNKNOWN);
-		gs_app_set_state (new_app, GS_APP_STATE_UPDATABLE);
-	}
-
-	/* save any properties we already know */
-	if (gs_app_get_sources(app)->len > 0)
-		gs_app_set_sources (new_app, gs_app_get_sources (app));
-	if (gs_app_get_project_group (app) != NULL)
-		gs_app_set_project_group (new_app, gs_app_get_project_group (app));
-	if (gs_app_get_name (app) != NULL)
-		gs_app_set_name (new_app, gs_app_get_name (app));
-	if (gs_app_get_summary (app) != NULL)
-		gs_app_set_summary (new_app, gs_app_get_summary (app));
-	if (gs_app_get_description (app) != NULL)
-		gs_app_set_description (new_app, gs_app_get_description (app));
-	if (gs_app_get_update_details (app) != NULL)
-		gs_app_set_update_details (new_app, gs_app_get_update_details (app));
-	if (gs_app_get_update_version (app) != NULL)
-		gs_app_set_update_version (new_app, gs_app_get_update_version (app));
-	if (gs_app_get_pixbuf (app) != NULL)
-		gs_app_set_pixbuf (new_app, gs_app_get_pixbuf (app));
-
-	/* now emit all the changed signals */
-	g_object_thaw_notify (G_OBJECT (new_app));
+	/* import all the useful properties */
+	gs_app_subsume (new_app, app);
 
 	/* this looks a little odd to unref the method parameter,
 	 * but it allows us to do:
@@ -211,7 +183,7 @@ gs_plugin_loader_run_refine_plugin (GsPluginLoader *plugin_loader,
 					      function_name_parent,
 					      function_name);
 	}
-	gs_profile_start_full (plugin_loader->priv->profile, profile_id);
+	gs_profile_start (plugin_loader->priv->profile, profile_id);
 	ret = plugin_func (plugin, list, flags, cancellable, error);
 	if (!ret) {
 		/* check the plugin is well behaved and sets error
@@ -236,7 +208,7 @@ gs_plugin_loader_run_refine_plugin (GsPluginLoader *plugin_loader,
 	}
 out:
 	if (profile_id != NULL) {
-		gs_profile_stop_full (plugin_loader->priv->profile, profile_id);
+		gs_profile_stop (plugin_loader->priv->profile, profile_id);
 		gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_FINISHED);
 	}
 	g_free (profile_id);
@@ -335,6 +307,7 @@ out:
 static GList *
 gs_plugin_loader_run_results (GsPluginLoader *plugin_loader,
 			      const gchar *function_name,
+			      GsPluginRefineFlags flags,
 			      GCancellable *cancellable,
 			      GError **error)
 {
@@ -381,7 +354,7 @@ gs_plugin_loader_run_results (GsPluginLoader *plugin_loader,
 	ret = gs_plugin_loader_run_refine (plugin_loader,
 					   function_name,
 					   list,
-					   GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+					   flags,
 					   cancellable,
 					   error);
 	if (!ret)
@@ -394,7 +367,7 @@ gs_plugin_loader_run_results (GsPluginLoader *plugin_loader,
 	if (list == NULL) {
 		g_set_error (error,
 			     GS_PLUGIN_LOADER_ERROR,
-			     GS_PLUGIN_LOADER_ERROR_FAILED,
+			     GS_PLUGIN_LOADER_ERROR_NO_RESULTS,
 			     "no results to show");
 		goto out;
 	}
@@ -517,6 +490,17 @@ gs_plugin_loader_get_app_is_compatible (GsApp *app, gpointer user_data)
 	return FALSE;
 }
 
+/**
+ * gs_plugin_loader_get_app_has_appdata:
+ */
+static gboolean
+gs_plugin_loader_get_app_has_appdata (GsApp *app, gpointer user_data)
+{
+	if (gs_app_get_description (app) != NULL)
+		return TRUE;
+	g_debug ("removing app with no AppData %s", gs_app_get_id (app));
+	return FALSE;
+}
 
 /**
  * gs_plugin_loader_run_action_plugin:
@@ -779,6 +763,7 @@ gs_plugin_loader_get_updates_thread_cb (GSimpleAsyncResult *res,
 
 	state->list = gs_plugin_loader_run_results (plugin_loader,
 						    method_name,
+						    state->flags,
 						    cancellable,
 						    &error);
 	if (state->list == NULL) {
@@ -802,7 +787,7 @@ gs_plugin_loader_get_updates_thread_cb (GSimpleAsyncResult *res,
 	if (state->list == NULL) {
 		g_set_error_literal (&error,
 				     GS_PLUGIN_LOADER_ERROR,
-				     GS_PLUGIN_LOADER_ERROR_FAILED,
+				     GS_PLUGIN_LOADER_ERROR_NO_RESULTS,
 				     "no updates to show after invalid");
 		gs_plugin_loader_get_all_state_finish (state, error);
 		g_error_free (error);
@@ -914,6 +899,7 @@ gs_plugin_loader_get_installed_thread_cb (GSimpleAsyncResult *res,
 	/* do things that would block */
 	state->list = gs_plugin_loader_run_results (plugin_loader,
 						    "gs_plugin_add_installed",
+						    state->flags,
 						    cancellable,
 						    &error);
 	state->list = g_list_concat (state->list, g_list_copy_deep (plugin_loader->priv->queued_installs, (GCopyFunc)g_object_ref, NULL));
@@ -929,7 +915,7 @@ gs_plugin_loader_get_installed_thread_cb (GSimpleAsyncResult *res,
 	if (state->list == NULL) {
 		g_set_error_literal (&error,
 				     GS_PLUGIN_LOADER_ERROR,
-				     GS_PLUGIN_LOADER_ERROR_FAILED,
+				     GS_PLUGIN_LOADER_ERROR_NO_RESULTS,
 				     "no installed applications to show after invalid");
 		gs_plugin_loader_get_all_state_finish (state, error);
 		g_error_free (error);
@@ -1040,6 +1026,7 @@ gs_plugin_loader_get_popular_thread_cb (GSimpleAsyncResult *res,
 	/* do things that would block */
 	state->list = gs_plugin_loader_run_results (plugin_loader,
 						    "gs_plugin_add_popular",
+						    state->flags,
 						    cancellable,
 						    &error);
 	if (state->list == NULL) {
@@ -1053,7 +1040,7 @@ gs_plugin_loader_get_popular_thread_cb (GSimpleAsyncResult *res,
 	if (state->list == NULL) {
 		g_set_error_literal (&error,
 				     GS_PLUGIN_LOADER_ERROR,
-				     GS_PLUGIN_LOADER_ERROR_FAILED,
+				     GS_PLUGIN_LOADER_ERROR_NO_RESULTS,
 				     "no popular apps to show");
 		gs_plugin_loader_get_all_state_finish (state, error);
 		g_error_free (error);
@@ -1146,6 +1133,7 @@ gs_plugin_loader_get_featured_thread_cb (GSimpleAsyncResult *res,
 	/* do things that would block */
 	state->list = gs_plugin_loader_run_results (plugin_loader,
 						    "gs_plugin_add_featured",
+						    state->flags,
 						    cancellable,
 						    &error);
 	if (state->list == NULL) {
@@ -1159,7 +1147,7 @@ gs_plugin_loader_get_featured_thread_cb (GSimpleAsyncResult *res,
 	if (state->list == NULL) {
 		g_set_error_literal (&error,
 				     GS_PLUGIN_LOADER_ERROR,
-				     GS_PLUGIN_LOADER_ERROR_FAILED,
+				     GS_PLUGIN_LOADER_ERROR_NO_RESULTS,
 				     "no featured apps to show");
 		gs_plugin_loader_get_all_state_finish (state, error);
 		g_error_free (error);
@@ -1339,9 +1327,11 @@ gs_plugin_loader_search_thread_cb (GSimpleAsyncResult *res,
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (object);
 	GsPlugin *plugin;
 	GsPluginSearchFunc plugin_func = NULL;
+	gchar **values;
 	guint i;
 
 	/* run each plugin */
+	values = g_str_tokenize_and_fold (state->value, NULL, NULL);
 	for (i = 0; i < plugin_loader->priv->plugins->len; i++) {
 		plugin = g_ptr_array_index (plugin_loader->priv->plugins, i);
 		if (!plugin->enabled)
@@ -1360,7 +1350,7 @@ gs_plugin_loader_search_thread_cb (GSimpleAsyncResult *res,
 		profile_id = g_strdup_printf ("GsPlugin::%s(%s)",
 					      plugin->name, function_name);
 		gs_profile_start (plugin_loader->priv->profile, profile_id);
-		ret = plugin_func (plugin, state->value, &state->list, cancellable, &error);
+		ret = plugin_func (plugin, values, &state->list, cancellable, &error);
 		if (!ret) {
 			gs_plugin_loader_get_all_state_finish (state, error);
 			g_error_free (error);
@@ -1394,10 +1384,15 @@ gs_plugin_loader_search_thread_cb (GSimpleAsyncResult *res,
 	gs_plugin_list_filter_duplicates (&state->list);
 	gs_plugin_list_filter (&state->list, gs_plugin_loader_app_is_valid, NULL);
 	gs_plugin_list_filter (&state->list, gs_plugin_loader_get_app_is_compatible, plugin_loader);
+	if (g_settings_get_boolean (plugin_loader->priv->settings, "require-appdata")) {
+		gs_plugin_list_filter (&state->list,
+				       gs_plugin_loader_get_app_has_appdata,
+				       plugin_loader);
+	}
 	if (state->list == NULL) {
 		g_set_error (&error,
 			     GS_PLUGIN_LOADER_ERROR,
-			     GS_PLUGIN_LOADER_ERROR_FAILED,
+			     GS_PLUGIN_LOADER_ERROR_NO_RESULTS,
 			     "no search results to show");
 		gs_plugin_loader_get_all_state_finish (state, error);
 		g_error_free (error);
@@ -1408,7 +1403,7 @@ gs_plugin_loader_search_thread_cb (GSimpleAsyncResult *res,
 	state->ret = TRUE;
 	gs_plugin_loader_get_all_state_finish (state, NULL);
 out:
-	return;
+	g_strfreev (values);
 }
 
 /**
@@ -1563,7 +1558,7 @@ gs_plugin_loader_get_categories_thread_cb (GSimpleAsyncResult *res,
 	if (state->list == NULL) {
 		g_set_error (&error,
 			     GS_PLUGIN_LOADER_ERROR,
-			     GS_PLUGIN_LOADER_ERROR_FAILED,
+			     GS_PLUGIN_LOADER_ERROR_NO_RESULTS,
 			     "no categories to show");
 		gs_plugin_loader_get_all_state_finish (state, error);
 		g_error_free (error);
@@ -1716,7 +1711,7 @@ gs_plugin_loader_get_category_apps_thread_cb (GSimpleAsyncResult *res,
 	if (state->list == NULL) {
 		g_set_error (&error,
 			     GS_PLUGIN_LOADER_ERROR,
-			     GS_PLUGIN_LOADER_ERROR_FAILED,
+			     GS_PLUGIN_LOADER_ERROR_NO_RESULTS,
 			     "no get_category_apps results to show");
 		gs_plugin_loader_get_all_state_finish (state, error);
 		g_error_free (error);
@@ -2392,6 +2387,17 @@ gs_plugin_loader_status_update_cb (GsPlugin *plugin,
 		       0, app, status);
 }
 
+/**
+ * gs_plugin_loader_updates_changed_cb:
+ */
+static void
+gs_plugin_loader_updates_changed_cb (GsPlugin *plugin, gpointer user_data)
+{
+	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (user_data);
+	g_debug ("updates-changed");
+	g_signal_emit (plugin_loader, signals[SIGNAL_UPDATES_CHANGED], 0);
+}
+
 /**
  * gs_plugin_loader_open_plugin:
  */
@@ -2441,6 +2447,8 @@ gs_plugin_loader_open_plugin (GsPluginLoader *plugin_loader,
 	plugin->name = g_strdup (plugin_name ());
 	plugin->status_update_fn = gs_plugin_loader_status_update_cb;
 	plugin->status_update_user_data = plugin_loader;
+	plugin->updates_changed_fn = gs_plugin_loader_updates_changed_cb;
+	plugin->updates_changed_user_data = plugin_loader;
 	plugin->profile = g_object_ref (plugin_loader->priv->profile);
 	plugin->icon_cache = g_hash_table_ref (plugin_loader->priv->icon_cache);
 	g_debug ("opened plugin %s: %s", filename, plugin->name);
@@ -2598,6 +2606,12 @@ gs_plugin_loader_class_init (GsPluginLoaderClass *klass)
 			      G_STRUCT_OFFSET (GsPluginLoaderClass, pending_apps_changed),
 			      NULL, NULL, g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
+	signals [SIGNAL_UPDATES_CHANGED] =
+		g_signal_new ("updates-changed",
+			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GsPluginLoaderClass, updates_changed),
+			      NULL, NULL, g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
 
 	g_type_class_add_private (klass, sizeof (GsPluginLoaderPrivate));
 }
@@ -2609,12 +2623,15 @@ static void
 gs_plugin_loader_init (GsPluginLoader *plugin_loader)
 {
 	const gchar *tmp;
+	gchar **projects;
+	guint i;
 
 	plugin_loader->priv = GS_PLUGIN_LOADER_GET_PRIVATE (plugin_loader);
 	plugin_loader->priv->plugins = g_ptr_array_new_with_free_func ((GDestroyNotify) gs_plugin_loader_plugin_free);
 	plugin_loader->priv->status_last = GS_PLUGIN_STATUS_LAST;
 	plugin_loader->priv->pending_apps = g_ptr_array_new_with_free_func ((GFreeFunc) g_object_unref);
 	plugin_loader->priv->profile = gs_profile_new ();
+	plugin_loader->priv->settings = g_settings_new ("org.gnome.software");
 	plugin_loader->priv->app_cache = g_hash_table_new_full (g_str_hash,
 								g_str_equal,
 								g_free,
@@ -2632,9 +2649,15 @@ gs_plugin_loader_init (GsPluginLoader *plugin_loader)
 
 	/* by default we only show project-less apps or compatible projects */
 	tmp = g_getenv ("GNOME_SOFTWARE_COMPATIBLE_PROJECTS");
-	if (tmp == NULL)
-		tmp = "GNOME";
-	plugin_loader->priv->compatible_projects = g_strsplit (tmp, ",", -1);
+	if (tmp == NULL) {
+		projects = g_settings_get_strv (plugin_loader->priv->settings,
+						"compatible-projects");
+	} else {
+		projects = g_strsplit (tmp, ",", -1);
+	}
+	for (i = 0; projects[i] != NULL; i++)
+		g_debug ("compatible-project: %s", projects[i]);
+	plugin_loader->priv->compatible_projects = projects;
 }
 
 /**
@@ -2659,6 +2682,7 @@ gs_plugin_loader_finalize (GObject *object)
 	/* run the plugins */
 	gs_plugin_loader_run (plugin_loader, "gs_plugin_destroy");
 
+	g_object_unref (plugin_loader->priv->settings);
 	g_object_unref (plugin_loader->priv->profile);
 	g_strfreev (plugin_loader->priv->compatible_projects);
 	g_hash_table_unref (plugin_loader->priv->app_cache);
