@@ -149,14 +149,11 @@ check_offline_update_cb (gpointer user_data)
 		title = ngettext ("Software Update Installed",
 				  "Software Updates Installed",
 				  num_packages);
-                /* TRANSLATORS: message when we've done offline updates */
+		/* TRANSLATORS: message when we've done offline updates */
 		message = ngettext ("An important OS update has been installed.",
 				    "Important OS updates have been installed.",
 				    num_packages);
-
-                gs_offline_updates_clear_status ();
-
-        } else {
+	} else {
 
 		title = _("Software Updates Failed");
 		/* TRANSLATORS: message when we offline updates have failed */
@@ -165,7 +162,7 @@ check_offline_update_cb (gpointer user_data)
 
 	notification = g_notification_new (title);
 	g_notification_set_body (notification, message);
-	icon = g_themed_icon_new ("software-update-urgent-symbolic");
+	icon = g_themed_icon_new ("gnome-software-symbolic");
 	g_notification_set_icon (notification, icon);
 	g_object_unref (icon);
 	if (success)
