@@ -96,6 +96,7 @@ void		 appstream_app_set_project_group	(AppstreamApp	*app,
 							 const gchar	*project_group,
 							 gsize		 length);
 void		 appstream_app_set_description		(AppstreamApp	*app,
+							 const gchar    *lang,
 							 const gchar	*description,
 							 gssize		 length);
 void		 appstream_app_set_icon			(AppstreamApp	*app,
@@ -126,7 +127,7 @@ void		 appstream_app_add_screenshot		(AppstreamApp	*app,
 							 AppstreamScreenshot *screenshot);
 GPtrArray	*appstream_app_get_screenshots		(AppstreamApp	*app);
 GPtrArray	*appstream_app_get_categories		(AppstreamApp	*app);
-gboolean	 appstream_app_search_matches		(AppstreamApp	*app,
+guint		 appstream_app_search_matches		(AppstreamApp	*app,
 							 const gchar	*search);
 
 G_END_DECLS
