@@ -231,8 +231,10 @@ gs_plugin_refine (GsPlugin *plugin,
 		if (gs_app_get_rating (app) != -1)
 			continue;
 		rating = gs_plugin_local_find_app (plugin, gs_app_get_id (app));
-		if (rating != -1)
+		if (rating != -1) {
 			gs_app_set_rating (app, rating);
+			gs_app_set_rating_kind (app, GS_APP_RATING_KIND_USER);
+		}
 	}
 out:
 	return ret;
