@@ -29,7 +29,8 @@
 #define GS_PLUGIN_PACKAGEKIT_HISTORY_TIMEOUT	5000 /* ms */
 
 struct GsPluginPrivate {
-	GDBusProxy		*proxy;
+	gsize			 loaded;
+	GDBusConnection		*connection;
 };
 
 /**
@@ -47,23 +48,7 @@ gs_plugin_get_name (void)
 void
 gs_plugin_initialize (GsPlugin *plugin)
 {
-	GError *error = NULL;
-
-	/* create private area */
 	plugin->priv = GS_PLUGIN_GET_PRIVATE (GsPluginPrivate);
-	plugin->priv->proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
-							     G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES |
-							     G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
-							     NULL,
-							     "org.freedesktop.PackageKit",
-							     "/org/freedesktop/PackageKit",
-							     "org.freedesktop.PackageKit",
-							     NULL,
-							     &error);
-	if (plugin->priv->proxy == NULL) {
-		g_warning ("Failed to create proxy for PackageKit: %s", error->message);
-		g_error_free (error);
-	}
 }
 
 /**
@@ -81,7 +66,8 @@ gs_plugin_get_priority (GsPlugin *plugin)
 void
 gs_plugin_destroy (GsPlugin *plugin)
 {
-	g_object_unref (plugin->priv->proxy);
+	if (plugin->priv->connection != NULL)
+		g_object_unref (plugin->priv->connection);
 }
 
 /**
@@ -97,7 +83,7 @@ gs_plugin_packagekit_refine_add_history (GsApp *app, GVariant *dict)
 	PkInfoEnum info_enum;
 
 	/* create new history item with same ID as parent */
-	history = gs_app_new (gs_app_get_id (app));
+	history = gs_app_new (gs_app_get_id_full (app));
 	gs_app_set_kind (history, GS_APP_KIND_PACKAGE);
 	gs_app_set_name (history, gs_app_get_name (app));
 
@@ -145,13 +131,28 @@ out:
 	g_object_unref (history);
 }
 
+/**
+ * gs_plugin_load:
+ */
+static gboolean
+gs_plugin_load (GsPlugin *plugin, GCancellable *cancellable, GError **error)
+{
+	gboolean ret = TRUE;
+	plugin->priv->connection = g_bus_get_sync (G_BUS_TYPE_SYSTEM,
+						   cancellable,
+						   error);
+	if (plugin->priv->connection == NULL)
+		ret = FALSE;
+	return ret;
+}
+
 static gboolean
 gs_plugin_packagekit_refine (GsPlugin *plugin,
 			     GList *list,
 			     GCancellable *cancellable,
 			     GError **error)
 {
-	const gchar **package_names;
+	const gchar **package_names = NULL;
 	gboolean ret = TRUE;
 	GError *error_local = NULL;
 	GList *l;
@@ -159,25 +160,37 @@ gs_plugin_packagekit_refine (GsPlugin *plugin,
 	GsApp *app_dummy;
 	guint i = 0;
 	GVariantIter iter;
-	GVariant *result;
+	GVariant *result = NULL;
 	GVariant *tuple = NULL;
 	GVariant *value;
 
+	/* already loaded */
+	if (g_once_init_enter (&plugin->priv->loaded)) {
+		ret = gs_plugin_load (plugin, cancellable, error);
+		g_once_init_leave (&plugin->priv->loaded, TRUE);
+		if (!ret)
+			goto out;
+	}
+
 	/* get an array of package names */
 	package_names = g_new0 (const gchar *, g_list_length (list) + 1);
 	for (l = list; l != NULL; l = l->next) {
 		app = GS_APP (l->data);
-		package_names[i++] = gs_app_get_source (app);
+		package_names[i++] = gs_app_get_source_default (app);
 	}
 
 	g_debug ("getting history for %i packages", g_list_length (list));
-	result = g_dbus_proxy_call_sync (plugin->priv->proxy,
-					 "GetPackageHistory",
-					 g_variant_new ("(^asu)", package_names, 0),
-					 G_DBUS_CALL_FLAGS_NONE,
-					 GS_PLUGIN_PACKAGEKIT_HISTORY_TIMEOUT,
-					 cancellable,
-					 &error_local);
+	result = g_dbus_connection_call_sync (plugin->priv->connection,
+					      "org.freedesktop.PackageKit",
+					      "/org/freedesktop/PackageKit",
+					      "org.freedesktop.PackageKit",
+					      "GetPackageHistory",
+					      g_variant_new ("(^asu)", package_names, 0),
+					      NULL,
+					      G_DBUS_CALL_FLAGS_NONE,
+					      GS_PLUGIN_PACKAGEKIT_HISTORY_TIMEOUT,
+					      cancellable,
+					      &error_local);
 	if (result == NULL) {
 		if (g_error_matches (error_local,
 				     G_DBUS_ERROR,
@@ -214,14 +227,14 @@ gs_plugin_packagekit_refine (GsPlugin *plugin,
 	for (l = list; l != NULL; l = l->next) {
 		app = GS_APP (l->data);
 		ret = g_variant_lookup (tuple,
-					gs_app_get_source (app),
+					gs_app_get_source_default (app),
 					"@aa{sv}",
 					&value);
 		if (!ret) {
 			/* make up a fake entry as we know this package was at
 			 * least installed at some point in time */
 			if (gs_app_get_state (app) == GS_APP_STATE_INSTALLED) {
-				app_dummy = gs_app_new (gs_app_get_id (app));
+				app_dummy = gs_app_new (gs_app_get_id_full (app));
 				gs_app_set_install_date (app_dummy, GS_APP_INSTALL_DATE_UNKNOWN);
 				gs_app_set_kind (app_dummy, GS_APP_KIND_PACKAGE);
 				gs_app_set_state (app_dummy, GS_APP_STATE_INSTALLED);
@@ -258,6 +271,7 @@ out:
 gboolean
 gs_plugin_refine (GsPlugin *plugin,
 		  GList *list,
+		  GsPluginRefineFlags flags,
 		  GCancellable *cancellable,
 		  GError **error)
 {
@@ -265,11 +279,16 @@ gs_plugin_refine (GsPlugin *plugin,
 	GList *l;
 	GList *packages = NULL;
 	GsApp *app;
+	GPtrArray *sources;
+
+	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_HISTORY) == 0)
+		goto out;
 
 	/* add any missing history data */
 	for (l = list; l != NULL; l = l->next) {
 		app = GS_APP (l->data);
-		if (gs_app_get_source (app) == NULL)
+		sources = gs_app_get_sources (app);
+		if (sources->len == 0)
 			continue;
 		if (gs_app_get_install_date (app) != 0)
 			continue;
