@@ -95,11 +95,11 @@ gs_plugin_packagekit_progress_cb (PkProgress *progress,
 
 	/* profile */
 	if (status == PK_STATUS_ENUM_SETUP) {
-		gs_profile_start_full (plugin->profile,
-				       "packagekit-refine::transaction");
+		gs_profile_start (plugin->profile,
+				  "packagekit-refine::transaction");
 	} else if (status == PK_STATUS_ENUM_FINISHED) {
-		gs_profile_stop_full (plugin->profile,
-				      "packagekit-refine::transaction");
+		gs_profile_stop (plugin->profile,
+				 "packagekit-refine::transaction");
 	}
 
 	plugin_status = packagekit_status_enum_to_plugin_status (status);
@@ -539,7 +539,7 @@ gs_plugin_refine_require_details (GsPlugin *plugin,
 	GsApp *app;
 	gboolean ret = TRUE;
 
-	gs_profile_start_full (plugin->profile, "packagekit-refine[source->licence]");
+	gs_profile_start (plugin->profile, "packagekit-refine[source->licence]");
 	for (l = list; l != NULL; l = l->next) {
 		app = GS_APP (l->data);
 		if (gs_app_get_licence (app) != NULL &&
@@ -561,7 +561,7 @@ gs_plugin_refine_require_details (GsPlugin *plugin,
 	if (!ret)
 		goto out;
 out:
-	gs_profile_stop_full (plugin->profile, "packagekit-refine[source->licence]");
+	gs_profile_stop (plugin->profile, "packagekit-refine[source->licence]");
 	g_list_free (list_tmp);
 	return ret;
 }
@@ -579,6 +579,46 @@ gs_plugin_refine_requires_version (GsApp *app, GsPluginRefineFlags flags)
 	return (flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION) > 0;
 }
 
+/**
+ * gs_plugin_refine_requires_update_details:
+ */
+static gboolean
+gs_plugin_refine_requires_update_details (GsApp *app, GsPluginRefineFlags flags)
+{
+	const gchar *tmp;
+	tmp = gs_app_get_update_details (app);
+	if (tmp != NULL)
+		return FALSE;
+	return (flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_UPDATE_DETAILS) > 0;
+}
+
+/**
+ * gs_plugin_refine_requires_package_id:
+ */
+static gboolean
+gs_plugin_refine_requires_package_id (GsApp *app, GsPluginRefineFlags flags)
+{
+	const gchar *tmp;
+	tmp = gs_app_get_source_id_default (app);
+	if (tmp != NULL)
+		return FALSE;
+	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION) > 0)
+		return TRUE;
+	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENCE) > 0)
+		return TRUE;
+	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_URL) > 0)
+		return TRUE;
+	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_SIZE) > 0)
+		return TRUE;
+	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_DESCRIPTION) > 0)
+		return TRUE;
+	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION) > 0)
+		return TRUE;
+	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_UPDATE_DETAILS) > 0)
+		return TRUE;
+	return FALSE;
+}
+
 /**
  * gs_plugin_refine:
  */
@@ -598,7 +638,7 @@ gs_plugin_refine (GsPlugin *plugin,
 	gboolean ret = TRUE;
 
 	/* can we resolve in one go? */
-	gs_profile_start_full (plugin->profile, "packagekit-refine[name->id]");
+	gs_profile_start (plugin->profile, "packagekit-refine[name->id]");
 	for (l = list; l != NULL; l = l->next) {
 		app = GS_APP (l->data);
 		if (gs_app_get_source_id_default (app) != NULL)
@@ -609,6 +649,7 @@ gs_plugin_refine (GsPlugin *plugin,
 		if (sources->len == 0)
 			continue;
 		if (gs_app_get_state (app) == GS_APP_STATE_UNKNOWN ||
+		    gs_plugin_refine_requires_package_id (app, flags) ||
 		    gs_plugin_refine_requires_version (app, flags)) {
 			resolve_all = g_list_prepend (resolve_all, app);
 		}
@@ -621,10 +662,10 @@ gs_plugin_refine (GsPlugin *plugin,
 		if (!ret)
 			goto out;
 	}
-	gs_profile_stop_full (plugin->profile, "packagekit-refine[name->id]");
+	gs_profile_stop (plugin->profile, "packagekit-refine[name->id]");
 
 	/* set the package-id for an installed desktop file */
-	gs_profile_start_full (plugin->profile, "packagekit-refine[desktop-filename->id]");
+	gs_profile_start (plugin->profile, "packagekit-refine[desktop-filename->id]");
 	for (l = list; l != NULL; l = l->next) {
 		if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_SETUP_ACTION) == 0)
 			continue;
@@ -642,19 +683,16 @@ gs_plugin_refine (GsPlugin *plugin,
 		if (!ret)
 			goto out;
 	}
-	gs_profile_stop_full (plugin->profile, "packagekit-refine[desktop-filename->id]");
+	gs_profile_stop (plugin->profile, "packagekit-refine[desktop-filename->id]");
 
 	/* any update details missing? */
-	gs_profile_start_full (plugin->profile, "packagekit-refine[id->update-details]");
+	gs_profile_start (plugin->profile, "packagekit-refine[id->update-details]");
 	for (l = list; l != NULL; l = l->next) {
 		app = GS_APP (l->data);
 		if (gs_app_get_state (app) != GS_APP_STATE_UPDATABLE)
 			continue;
-		if (gs_app_get_update_details (app) != NULL)
-			continue;
-		if (gs_app_get_source_id_default (app) == NULL)
-			continue;
-		updatedetails_all = g_list_prepend (updatedetails_all, app);
+		if (gs_plugin_refine_requires_update_details (app, flags))
+			updatedetails_all = g_list_prepend (updatedetails_all, app);
 	}
 	if (updatedetails_all != NULL) {
 		ret = gs_plugin_packagekit_refine_updatedetails (plugin,
@@ -664,7 +702,7 @@ gs_plugin_refine (GsPlugin *plugin,
 		if (!ret)
 			goto out;
 	}
-	gs_profile_stop_full (plugin->profile, "packagekit-refine[id->update-details]");
+	gs_profile_stop (plugin->profile, "packagekit-refine[id->update-details]");
 
 	/* any important details missing? */
 	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENCE) > 0 ||
